@@ -317,22 +317,6 @@ const asn1_static_node pkix_asn1_tab[] = {
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "24"},
   { "InvalidityDate", 1073741861, NULL },
-  { "VisibleString", 1610620935, NULL },
-  { NULL, 4360, "26"},
-  { "NumericString", 1610620935, NULL },
-  { NULL, 4360, "18"},
-  { "IA5String", 1610620935, NULL },
-  { NULL, 4360, "22"},
-  { "TeletexString", 1610620935, NULL },
-  { NULL, 4360, "20"},
-  { "PrintableString", 1610620935, NULL },
-  { NULL, 4360, "19"},
-  { "UniversalString", 1610620935, NULL },
-  { NULL, 4360, "28"},
-  { "BMPString", 1610620935, NULL },
-  { NULL, 4360, "30"},
-  { "UTF8String", 1610620935, NULL },
-  { NULL, 4360, "12"},
   { "id-pkix", 1879048204, NULL },
   { "iso", 1073741825, "1"},
   { "identified-organization", 1073741825, "3"},
@@ -1282,7 +1266,41 @@ const asn1_static_node pkix_asn1_tab[] = {
   { "publicKeyAndChallenge", 1073741826, "PublicKeyAndChallenge"},
   { "signatureAlgorithm", 1073741826, "AlgorithmIdentifier"},
   { "signature", 6, NULL },
-  { "ExtensionRequest", 536870923, NULL },
+  { "ExtensionRequest", 1610612747, NULL },
   { NULL, 2, "Extension"},
+  { "id-ogrn", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "ru", 1073741825, "643"},
+  { NULL, 1073741825, "100"},
+  { NULL, 1, "1"},
+  { "OGRN", 1612709916, NULL },
+  { NULL, 1048586, "13"},
+  { "id-snils", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "ru", 1073741825, "643"},
+  { NULL, 1073741825, "100"},
+  { NULL, 1, "3"},
+  { "SNILS", 1612709916, NULL },
+  { NULL, 1048586, "11"},
+  { "id-ogrn", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "ru", 1073741825, "643"},
+  { NULL, 1073741825, "100"},
+  { NULL, 1, "5"},
+  { "OGRNIP", 1612709916, NULL },
+  { NULL, 1048586, "15"},
+  { "id-inn", 1879048204, NULL },
+  { "iso", 1073741825, "1"},
+  { "member-body", 1073741825, "2"},
+  { "ru", 1073741825, "643"},
+  { "reg3", 1073741825, "3"},
+  { "fns", 1073741825, "131"},
+  { NULL, 1073741825, "1"},
+  { "inn", 1, "1"},
+  { "INN", 538968092, NULL },
+  { NULL, 1048586, "12"},
   { NULL, 0, NULL }
 };
