@@ -666,7 +666,8 @@ gck_enumerator_class_init (GckEnumeratorClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_INTERACTION,
 		g_param_spec_object ("interaction", "Interaction", "Interaction asking for pins",
-		                     G_TYPE_TLS_INTERACTION, G_PARAM_READWRITE));
+		                     G_TYPE_TLS_INTERACTION,
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GckEnumerator:object-type: (skip)
@@ -676,7 +677,8 @@ gck_enumerator_class_init (GckEnumeratorClass *klass)
 	 */
 	g_object_class_install_property (gobject_class, PROP_OBJECT_TYPE,
 		g_param_spec_gtype ("object-type", "Object Type", "Type of objects created",
-		                    GCK_TYPE_OBJECT, G_PARAM_READWRITE));
+		                    GCK_TYPE_OBJECT,
+		                    G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GckEnumerator:chained:
@@ -685,8 +687,9 @@ gck_enumerator_class_init (GckEnumeratorClass *klass)
 	 * has enumerated all its objects.
 	 */
 	g_object_class_install_property (gobject_class, PROP_CHAINED,
-	            g_param_spec_object ("chained", "Chained", "Chained enumerator",
-	                                 GCK_TYPE_ENUMERATOR, G_PARAM_READWRITE));
+		g_param_spec_object ("chained", "Chained", "Chained enumerator",
+		                     GCK_TYPE_ENUMERATOR,
+		                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -918,7 +921,7 @@ gck_enumerator_set_object_type_full (GckEnumerator *self,
  * Get the enumerator that will be run after all objects from this one
  * are seen.
  *
- * Returns: (transfer full) (allow-none): the chained enumerator or %NULL
+ * Returns: (transfer full) (nullable): the chained enumerator or %NULL
  */
 GckEnumerator *
 gck_enumerator_get_chained (GckEnumerator *self)
@@ -940,7 +943,7 @@ gck_enumerator_get_chained (GckEnumerator *self)
 /**
  * gck_enumerator_set_chained:
  * @self: the enumerator
- * @chained: (allow-none): the chained enumerator or %NULL
+ * @chained: (nullable): the chained enumerator or %NULL
  *
  * Set a chained enumerator that will be run after all objects from this one
  * are seen.
@@ -975,7 +978,7 @@ gck_enumerator_set_chained (GckEnumerator *self,
  *
  * Get the interaction used when a pin is needed
  *
- * Returns: (transfer full) (allow-none): the interaction or %NULL
+ * Returns: (transfer full) (nullable): the interaction or %NULL
  */
 GTlsInteraction *
 gck_enumerator_get_interaction (GckEnumerator *self)
@@ -997,7 +1000,7 @@ gck_enumerator_get_interaction (GckEnumerator *self)
 /**
  * gck_enumerator_set_interaction:
  * @self: the enumerator
- * @interaction: (allow-none): the interaction or %NULL
+ * @interaction: (nullable): the interaction or %NULL
  *
  * Set the interaction used when a pin is needed
  */
@@ -1181,7 +1184,7 @@ extract_results (GckEnumeratorState *state,
  * %NULL is also returned if the function fails. Use the @error to determine
  * whether a failure occurred or not.
  *
- * Returns: (transfer full) (allow-none): The next object, which must be released
+ * Returns: (transfer full) (nullable): The next object, which must be released
  * using g_object_unref, or %NULL.
  */
 GckObject *
