@@ -50,8 +50,6 @@ enum {
 	PROP_URI
 };
 
-typedef struct _GcrPkcs11ImporterClass GcrPkcs11ImporterClass;
-
 struct _GcrPkcs11Importer {
 	GObject parent;
 	GckSlot *slot;
@@ -62,10 +60,6 @@ struct _GcrPkcs11Importer {
 	gboolean any_private;
 };
 
-struct _GcrPkcs11ImporterClass {
-	GObjectClass parent_class;
-};
-
 typedef struct  {
 	GcrPkcs11Importer *importer;
 	GCancellable *cancellable;
@@ -856,7 +850,7 @@ _gcr_pkcs11_importer_import_async (GcrImporter *importer,
 	                                 _gcr_pkcs11_importer_import_async);
 	data = g_new0 (GcrImporterData, 1);
 	data->async = TRUE;
-	data->importer = g_object_ref (importer);
+	data->importer = GCR_PKCS11_IMPORTER (g_object_ref (importer));
 	data->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 	g_simple_async_result_set_op_res_gpointer (res, data, gcr_importer_data_free);
 
