@@ -181,17 +181,18 @@ _gcr_certificate_request_renderer_class_init (GcrCertificateRequestRendererClass
 	 */
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	           g_param_spec_boxed ("attributes", "Attributes", "Certificate pkcs11 attributes",
-	                               GCK_TYPE_ATTRIBUTES, G_PARAM_READWRITE));
+	                               GCK_TYPE_ATTRIBUTES,
+	                               G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GcrCertificateRequestRenderer:label:
 	 *
 	 * The label to display.
 	 */
-
 	g_object_class_install_property (gobject_class, PROP_LABEL,
 	           g_param_spec_string ("label", "Label", "Certificate Label",
-	                                "", G_PARAM_READWRITE));
+	                                "",
+	                                G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/* Register this as a renderer which can be loaded */
 	gck_builder_add_ulong (&builder, CKA_CLASS, CKO_GCR_CERTIFICATE_REQUEST);
@@ -430,7 +431,7 @@ _gcr_certificate_request_renderer_iface (GcrRendererIface *iface)
 
 /**
  * gcr_certificate_request_renderer_new_for_attributes:
- * @label: (allow-none): the label to display
+ * @label: (nullable): the label to display
  * @attrs: the attributes to display
  *
  * Create a new certificate request renderer to display the label and attributes.
@@ -456,7 +457,7 @@ _gcr_certificate_request_renderer_new_for_attributes (const gchar *label,
  *
  * Get the PKCS\#11 attributes, if any, set for this renderer to display.
  *
- * Returns: (allow-none) (transfer none): the attributes, owned by the renderer
+ * Returns: (nullable) (transfer none): the attributes, owned by the renderer
  */
 GckAttributes *
 _gcr_certificate_request_renderer_get_attributes (GcrCertificateRequestRenderer *self)
@@ -468,7 +469,7 @@ _gcr_certificate_request_renderer_get_attributes (GcrCertificateRequestRenderer
 /**
  * gcr_certificate_request_renderer_set_attributes:
  * @self: the renderer
- * @attrs: (allow-none): attributes to set
+ * @attrs: (nullable): attributes to set
  *
  * Set the PKCS\#11 attributes for this renderer to display. One of the attributes
  * should be a CKA_VALUE type attribute containing a DER encoded PKCS\#10
